==> QupZilla-2.2.3.tar.xz: QupZilla-2.2.3/src/plugins/TabManager/translations/he_IL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="he_IL" version="2.1">
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>הגדרות מנהל כרטיסיות</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>אנא בחר טיפוס תצוגה:</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>סרגל צד</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>חלון</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;הערה:&lt;/span&gt; טיפוס &amp;quot;חלון&amp;quot; הינו רצוי לצורך ניהול חלונות/כרטיסיות מרובים.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation>השתמש בתוסף TabManager בתור תחליף לסרגל כרטיסיות ראשי.</translation>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>מנהל כרטיסיות</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="106"/>
        <source>Local File System:</source>
        <translation>מערכת קבצים מקומית:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="109"/>
        <source>QupZilla:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="112"/>
        <source> [FTP]</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="266"/>
        <source>Group by</source>
        <translation>קבץ לפי</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="267"/>
        <source>&amp;Window</source>
        <translation>&amp;חלון</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="272"/>
        <source>&amp;Domain</source>
        <translation>מ&amp;תחם</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="277"/>
        <source>&amp;Host</source>
        <translation>&amp;מארח</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="285"/>
        <source>&amp;Show side by side</source>
        <translation>&amp;הצג זה לצד זה</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="291"/>
        <source>&amp;Detach checked tabs</source>
        <translation>ה&amp;פרד כרטיסיות מסומנות</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="292"/>
        <source>Book&amp;mark checked tabs</source>
        <translation>ס&amp;מן כרטיסיות מסומנות</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="293"/>
        <source>&amp;Close checked tabs</source>
        <translation>&amp;סגור כרטיסיות מסומנות</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="547"/>
        <source>Choose folder for bookmarks:</source>
        <translation>בחר תיקייה עבור סימניות:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="548"/>
        <source>Bookmark Selected Tabs</source>
        <translation>סמן כרטיסיות נבחרות</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="665"/>
        <source>Window %1</source>
        <translation>חלון %1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="666"/>
        <source>Double click to switch</source>
        <translation>לחיצה כפולה כדי להחליף</translation>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="46"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="51"/>
        <source>Tab Manager</source>
        <translation>מנהל כרטיסיות</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="79"/>
        <source>Show Tab Manager</source>
        <translation>הצג מנהל כרטיסיות</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.5.tar.xz: QupZilla-2.2.5/src/plugins/TabManager/translations/he_IL.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="he_IL" version="2.1">
<context>
    <name>TabManagerButton</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="50"/>
        <source>Tab Manager button</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>הגדרות מנהל כרטיסיות</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>תצוגה</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>אנא בחר טיפוס תצוגה:</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>סרגל צד</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>חלון</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;הערה:&lt;/span&gt; טיפוס &amp;quot;חלון&amp;quot; הינו רצוי לצורך ניהול חלונות/כרטיסיות מרובים.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation>השתמש בתוסף TabManager בתור תחליף לסרגל כרטיסיות ראשי.</translation>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>מנהל כרטיסיות</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="110"/>
        <source>Local File System:</source>
        <translation>מערכת קבצים מקומית:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="113"/>
        <source>QupZilla:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="116"/>
        <source> [FTP]</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="301"/>
        <source>Group by</source>
        <translation>קבץ לפי</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="302"/>
        <source>&amp;Window</source>
        <translation>&amp;חלון</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="307"/>
        <source>&amp;Domain</source>
        <translation>מ&amp;תחם</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="312"/>
        <source>&amp;Host</source>
        <translation>&amp;מארח</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="320"/>
        <source>&amp;Show side by side</source>
        <translation>&amp;הצג זה לצד זה</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="326"/>
        <source>&amp;Detach checked tabs</source>
        <translation>ה&amp;פרד כרטיסיות מסומנות</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="327"/>
        <source>Book&amp;mark checked tabs</source>
        <translation>ס&amp;מן כרטיסיות מסומנות</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="328"/>
        <source>&amp;Close checked tabs</source>
        <translation>&amp;סגור כרטיסיות מסומנות</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="329"/>
        <source>&amp;Unload checked tabs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="581"/>
        <source>Choose folder for bookmarks:</source>
        <translation>בחר תיקייה עבור סימניות:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="582"/>
        <source>Bookmark Selected Tabs</source>
        <translation>סמן כרטיסיות נבחרות</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="700"/>
        <source>Window %1</source>
        <translation>חלון %1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="701"/>
        <source>Double click to switch</source>
        <translation>לחיצה כפולה כדי להחליף</translation>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="68"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="73"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="99"/>
        <source>Tab Manager</source>
        <translation>מנהל כרטיסיות</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="100"/>
        <source>Show Tab Manager</source>
        <translation>הצג מנהל כרטיסיות</translation>
    </message>
</context>
</TS>
